@@ -37,21 +37,20 @@
 #include <ctime>
 
 
-static const char description[] =
-    I18N_NOOP("KSudoku - Sudokus and more");
-
 int main(int argc, char **argv)
 {
 	qsrand(std::time(nullptr));
 	// Fixes blurry icons with fractional scaling
-    QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
+#endif
     QApplication app(argc, argv);
 	KLocalizedString::setApplicationDomain("ksudoku");
 
 	KAboutData about(QStringLiteral("ksudoku"),
                      i18n("KSudoku"),
                      QLatin1String(KSUDOKU_VERSION_STRING),
-	                 i18n(description),
+	                 i18n("KSudoku - Sudokus and more"),
 	                 KAboutLicense::GPL_V2,
 	                 i18n("(c) 2005-2007 The KSudoku Authors"),
 	                 QString(), QStringLiteral("https://games.kde.org/games/ksudoku"));
@@ -75,9 +74,6 @@ int main(int argc, char **argv)
 
 	KCrash::initialize();
 
-	// register ourselves as a dcop client
-//	app.dcopClient()->registerAs(app.name(), false); //TODO PORT
-
 	KConfigDialogManager::changedMap()->insert(QStringLiteral("ksudoku::SymbolConfigListWidget"), SIGNAL(itemChanged(QListWidgetItem*)));
 
 	// see if we are starting with session management
